
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_CORBA_CDR_LittleEndianInputStream__
#define __gnu_CORBA_CDR_LittleEndianInputStream__

#pragma interface

#include <java/io/FilterInputStream.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace CORBA
    {
      namespace CDR
      {
          class LittleEndianInputStream;
      }
    }
  }
}

class gnu::CORBA::CDR::LittleEndianInputStream : public ::java::io::FilterInputStream
{

public:
  LittleEndianInputStream(::java::io::InputStream *);
  virtual jint read(JArray< jbyte > *);
  virtual jint read(JArray< jbyte > *, jint, jint);
  virtual jboolean readBoolean();
  virtual jbyte readByte();
  virtual jchar readChar();
  virtual jdouble readDouble();
  virtual jfloat readFloat();
  virtual void readFully(JArray< jbyte > *);
  virtual void readFully(JArray< jbyte > *, jint, jint);
  virtual jint readInt();
  virtual ::java::lang::String * readLine();
  virtual jlong readLong();
  virtual jshort readShort();
  virtual jint readUnsignedByte();
  virtual jint readUnsignedShort();
  virtual jint skipBytes(jint);
public: // actually protected
  virtual jboolean convertToBoolean(jint);
  virtual jbyte convertToByte(jint);
  virtual jint convertToUnsignedByte(jint);
  virtual jchar convertToChar(JArray< jbyte > *);
  virtual jshort convertToShort(JArray< jbyte > *);
  virtual jint convertToUnsignedShort(JArray< jbyte > *);
  virtual jint convertToInt(JArray< jbyte > *);
  virtual jlong convertToLong(JArray< jbyte > *);
public:
  virtual ::java::lang::String * readUTF();
public: // actually package-private
  JArray< jbyte > * __attribute__((aligned(__alignof__( ::java::io::FilterInputStream)))) buf;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_CORBA_CDR_LittleEndianInputStream__
