
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_assembly_DeflateTransformer__
#define __gnu_javax_crypto_assembly_DeflateTransformer__

#pragma interface

#include <gnu/javax/crypto/assembly/Transformer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace assembly
        {
            class DeflateTransformer;
        }
      }
    }
  }
}

class gnu::javax::crypto::assembly::DeflateTransformer : public ::gnu::javax::crypto::assembly::Transformer
{

public: // actually package-private
  DeflateTransformer();
  virtual void initDelegate(::java::util::Map *);
  virtual jint delegateBlockSize();
  virtual void resetDelegate();
  virtual JArray< jbyte > * updateDelegate(JArray< jbyte > *, jint, jint);
  virtual JArray< jbyte > * lastUpdateDelegate();
private:
  void compress();
  void decompress(JArray< jbyte > *, jint, jint);
  ::java::util::zip::Deflater * __attribute__((aligned(__alignof__( ::gnu::javax::crypto::assembly::Transformer)))) compressor;
  ::java::util::zip::Inflater * decompressor;
  jint outputBlockSize;
  JArray< jbyte > * zlibBuffer;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_crypto_assembly_DeflateTransformer__
