
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_keyring_PrivateKeyEntry__
#define __gnu_javax_crypto_keyring_PrivateKeyEntry__

#pragma interface

#include <gnu/javax/crypto/keyring/PrimitiveEntry.h>
extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace keyring
        {
            class PrivateKeyEntry;
            class Properties;
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
        class Key;
    }
  }
}

class gnu::javax::crypto::keyring::PrivateKeyEntry : public ::gnu::javax::crypto::keyring::PrimitiveEntry
{

public:
  PrivateKeyEntry(::java::security::Key *, ::java::util::Date *, ::gnu::javax::crypto::keyring::Properties *);
private:
  PrivateKeyEntry();
public:
  static ::gnu::javax::crypto::keyring::PrivateKeyEntry * decode(::java::io::DataInputStream *);
  ::java::security::Key * getKey();
public: // actually protected
  void encodePayload();
public:
  ::java::lang::String * toString();
  static const jint TYPE = 7;
private:
  ::java::security::Key * __attribute__((aligned(__alignof__( ::gnu::javax::crypto::keyring::PrimitiveEntry)))) key;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_crypto_keyring_PrivateKeyEntry__
