
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_Jessie__
#define __gnu_javax_net_ssl_provider_Jessie__

#pragma interface

#include <java/security/Provider.h>
extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
              class Jessie;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::Jessie : public ::java::security::Provider
{

public:
  Jessie();
private:
  static const jlong serialVersionUID = -1LL;
public:
  static ::java::lang::String * VERSION;
  static jdouble VERSION_DOUBLE;
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_net_ssl_provider_Jessie__
