
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_IAuthInfoProviderFactory__
#define __gnu_javax_crypto_sasl_IAuthInfoProviderFactory__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace sasl
        {
            class IAuthInfoProvider;
            class IAuthInfoProviderFactory;
        }
      }
    }
  }
}

class gnu::javax::crypto::sasl::IAuthInfoProviderFactory : public ::java::lang::Object
{

public:
  virtual ::gnu::javax::crypto::sasl::IAuthInfoProvider * getInstance(::java::lang::String *) = 0;
  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif // __gnu_javax_crypto_sasl_IAuthInfoProviderFactory__
