
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_sasl_NoSuchUserException__
#define __gnu_javax_crypto_sasl_NoSuchUserException__

#pragma interface

#include <javax/security/sasl/AuthenticationException.h>
extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace sasl
        {
            class NoSuchUserException;
        }
      }
    }
  }
}

class gnu::javax::crypto::sasl::NoSuchUserException : public ::javax::security::sasl::AuthenticationException
{

public:
  NoSuchUserException();
  NoSuchUserException(::java::lang::String *);
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_crypto_sasl_NoSuchUserException__
