
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_locale_Calendar_en__
#define __gnu_java_locale_Calendar_en__

#pragma interface

#include <java/util/ListResourceBundle.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace locale
      {
          class Calendar_en;
      }
    }
  }
}

class gnu::java::locale::Calendar_en : public ::java::util::ListResourceBundle
{

public:
  Calendar_en();
  virtual JArray< JArray< ::java::lang::Object * > * > * getContents();
private:
  static JArray< JArray< ::java::lang::Object * > * > * contents;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_java_locale_Calendar_en__
