
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_X509TrustManagerFactory__
#define __gnu_javax_net_ssl_provider_X509TrustManagerFactory__

#pragma interface

#include <javax/net/ssl/TrustManagerFactorySpi.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
              class X509TrustManagerFactory;
              class X509TrustManagerFactory$Manager;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
        class KeyStore;
    }
  }
  namespace javax
  {
    namespace net
    {
      namespace ssl
      {
          class ManagerFactoryParameters;
          class TrustManager;
      }
    }
  }
}

class gnu::javax::net::ssl::provider::X509TrustManagerFactory : public ::javax::net::ssl::TrustManagerFactorySpi
{

public:
  X509TrustManagerFactory();
public: // actually protected
  virtual JArray< ::javax::net::ssl::TrustManager * > * engineGetTrustManagers();
  virtual void engineInit(::javax::net::ssl::ManagerFactoryParameters *);
  virtual void engineInit(::java::security::KeyStore *);
private:
  static ::java::lang::String * sep;
  static ::java::lang::String * JSSE_CERTS;
  static ::java::lang::String * CA_CERTS;
  ::gnu::javax::net::ssl::provider::X509TrustManagerFactory$Manager * __attribute__((aligned(__alignof__( ::javax::net::ssl::TrustManagerFactorySpi)))) current;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_net_ssl_provider_X509TrustManagerFactory__
