
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_xlib_XConnectException__
#define __gnu_gcj_xlib_XConnectException__

#pragma interface

#include <java/io/IOException.h>
extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace xlib
      {
          class XConnectException;
      }
    }
  }
}

class gnu::gcj::xlib::XConnectException : public ::java::io::IOException
{

public:
  XConnectException();
  XConnectException(::java::lang::String *);
  static ::java::lang::Class class$;
};

#endif // __gnu_gcj_xlib_XConnectException__
