
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_xml_pipeline_ValidationConsumer$ChildrenRecognizer__
#define __gnu_xml_pipeline_ValidationConsumer$ChildrenRecognizer__

#pragma interface

#include <gnu/xml/pipeline/ValidationConsumer$Recognizer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace xml
    {
      namespace pipeline
      {
          class ValidationConsumer;
          class ValidationConsumer$ChildrenRecognizer;
          class ValidationConsumer$ElementInfo;
          class ValidationConsumer$Recognizer;
      }
    }
  }
}

class gnu::xml::pipeline::ValidationConsumer$ChildrenRecognizer : public ::gnu::xml::pipeline::ValidationConsumer$Recognizer
{

  void copyIn(::gnu::xml::pipeline::ValidationConsumer$ChildrenRecognizer *);
public:
  ValidationConsumer$ChildrenRecognizer(::gnu::xml::pipeline::ValidationConsumer$ElementInfo *, ::gnu::xml::pipeline::ValidationConsumer *);
private:
  ValidationConsumer$ChildrenRecognizer(::gnu::xml::pipeline::ValidationConsumer *, ::gnu::xml::pipeline::ValidationConsumer$ElementInfo *);
  ::gnu::xml::pipeline::ValidationConsumer$ChildrenRecognizer * shallowClone();
  ::gnu::xml::pipeline::ValidationConsumer$ChildrenRecognizer * deepClone();
  ::gnu::xml::pipeline::ValidationConsumer$ChildrenRecognizer * deepClone(::java::util::Hashtable *);
  void patchNext(::gnu::xml::pipeline::ValidationConsumer$Recognizer *, ::java::util::Hashtable *);
  jint populate(JArray< jchar > *, jint);
public: // actually package-private
  jboolean acceptCharacters();
  ::gnu::xml::pipeline::ValidationConsumer$Recognizer * acceptElement(::java::lang::String *);
  jboolean completed();
private:
  ::gnu::xml::pipeline::ValidationConsumer * __attribute__((aligned(__alignof__( ::gnu::xml::pipeline::ValidationConsumer$Recognizer)))) consumer;
  JArray< ::gnu::xml::pipeline::ValidationConsumer$Recognizer * > * components;
  ::java::lang::String * name;
  ::gnu::xml::pipeline::ValidationConsumer$Recognizer * next;
  jint flags;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_xml_pipeline_ValidationConsumer$ChildrenRecognizer__
