
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_naming_giop_ListEnumeration__
#define __gnu_javax_naming_giop_ListEnumeration__

#pragma interface

#include <gnu/javax/naming/giop/GiopNamingEnumeration.h>
extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace naming
      {
        namespace giop
        {
            class ListEnumeration;
        }
      }
    }
  }
  namespace org
  {
    namespace omg
    {
      namespace CosNaming
      {
          class Binding;
          class BindingIteratorHolder;
          class BindingListHolder;
      }
    }
  }
}

class gnu::javax::naming::giop::ListEnumeration : public ::gnu::javax::naming::giop::GiopNamingEnumeration
{

public:
  ListEnumeration(::org::omg::CosNaming::BindingListHolder *, ::org::omg::CosNaming::BindingIteratorHolder *, jint);
  virtual ::java::lang::Object * convert(::org::omg::CosNaming::Binding *);
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_naming_giop_ListEnumeration__
