
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_SSLv3HMacMD5Impl__
#define __gnu_javax_net_ssl_provider_SSLv3HMacMD5Impl__

#pragma interface

#include <javax/crypto/MacSpi.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
              class SSLHMac;
              class SSLv3HMacMD5Impl;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
        class Key;
      namespace spec
      {
          class AlgorithmParameterSpec;
      }
    }
  }
}

class gnu::javax::net::ssl::provider::SSLv3HMacMD5Impl : public ::javax::crypto::MacSpi
{

public:
  SSLv3HMacMD5Impl();
public: // actually protected
  virtual JArray< jbyte > * engineDoFinal();
  virtual jint engineGetMacLength();
  virtual void engineInit(::java::security::Key *, ::java::security::spec::AlgorithmParameterSpec *);
  virtual void engineReset();
  virtual void engineUpdate(jbyte);
  virtual void engineUpdate(JArray< jbyte > *, jint, jint);
private:
  ::gnu::javax::net::ssl::provider::SSLHMac * __attribute__((aligned(__alignof__( ::javax::crypto::MacSpi)))) adaptee;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_net_ssl_provider_SSLv3HMacMD5Impl__
