
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_peer_gtk_GtkCheckboxPeer__
#define __gnu_java_awt_peer_gtk_GtkCheckboxPeer__

#pragma interface

#include <gnu/java/awt/peer/gtk/GtkComponentPeer.h>
extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace peer
        {
          namespace gtk
          {
              class GtkCheckboxPeer;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
        class Checkbox;
        class CheckboxGroup;
    }
  }
}

class gnu::java::awt::peer::gtk::GtkCheckboxPeer : public ::gnu::java::awt::peer::gtk::GtkComponentPeer
{

public:
  virtual void createCheckButton();
  virtual void createRadioButton(jlong);
  virtual void addToGroup(jlong);
  virtual void removeFromGroup();
  virtual void switchToGroup(jlong);
  virtual void connectSignals();
public: // actually protected
  virtual void gtkWidgetModifyFont(::java::lang::String *, jint, jint);
public: // actually package-private
  virtual void gtkButtonSetLabel(::java::lang::String *);
  virtual void gtkToggleButtonSetActive(jboolean);
public:
  GtkCheckboxPeer(::java::awt::Checkbox *);
  virtual void create();
  virtual void setState(jboolean);
  virtual void setLabel(::java::lang::String *);
  virtual void setCheckboxGroup(::java::awt::CheckboxGroup *);
  virtual void postItemEvent(::java::lang::Object *, jboolean);
  virtual void addToGroupMap(jlong);
  virtual void dispose();
  ::java::awt::CheckboxGroup * __attribute__((aligned(__alignof__( ::gnu::java::awt::peer::gtk::GtkComponentPeer)))) current_group;
private:
  jboolean currentState;
  static ::java::util::WeakHashMap * groupMap;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_java_awt_peer_gtk_GtkCheckboxPeer__
