
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_beans_decoder_PersistenceParser$Creator__
#define __gnu_java_beans_decoder_PersistenceParser$Creator__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace beans
      {
        namespace decoder
        {
            class AbstractElementHandler;
            class ElementHandler;
            class PersistenceParser$Creator;
        }
      }
    }
  }
}

class gnu::java::beans::decoder::PersistenceParser$Creator : public ::java::lang::Object
{

public:
  virtual ::gnu::java::beans::decoder::AbstractElementHandler * createHandler(::gnu::java::beans::decoder::ElementHandler *) = 0;
  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif // __gnu_java_beans_decoder_PersistenceParser$Creator__
