
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_peer_gtk_GtkLabelPeer__
#define __gnu_java_awt_peer_gtk_GtkLabelPeer__

#pragma interface

#include <gnu/java/awt/peer/gtk/GtkComponentPeer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace peer
        {
          namespace gtk
          {
              class GtkLabelPeer;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
        class Label;
    }
  }
}

class gnu::java::awt::peer::gtk::GtkLabelPeer : public ::gnu::java::awt::peer::gtk::GtkComponentPeer
{

public: // actually package-private
  virtual void create(::java::lang::String *, jfloat);
public: // actually protected
  virtual void gtkWidgetModifyFont(::java::lang::String *, jint, jint);
public: // actually package-private
  virtual void nativeSetAlignment(jfloat);
public:
  virtual void setNativeText(::java::lang::String *);
public: // actually package-private
  virtual void setNativeBounds(jint, jint, jint, jint);
  virtual void gtkWidgetGetPreferredDimensions(JArray< jint > *);
  virtual void create();
public:
  virtual void setText(::java::lang::String *);
  GtkLabelPeer(::java::awt::Label *);
  virtual void setAlignment(jint);
public: // actually package-private
  virtual jfloat getGtkAlignment(jint);
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_java_awt_peer_gtk_GtkLabelPeer__
