
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_jdwp_JdwpConstants$CommandSet$ArrayType__
#define __gnu_classpath_jdwp_JdwpConstants$CommandSet$ArrayType__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      namespace jdwp
      {
          class JdwpConstants$CommandSet$ArrayType;
      }
    }
  }
}

class gnu::classpath::jdwp::JdwpConstants$CommandSet$ArrayType : public ::java::lang::Object
{

public:
  JdwpConstants$CommandSet$ArrayType();
  static const jbyte CS_VALUE = 4;
  static const jbyte NEW_INSTANCE = 1;
  static ::java::lang::Class class$;
};

#endif // __gnu_classpath_jdwp_JdwpConstants$CommandSet$ArrayType__
