
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_awt_xlib_XEventQueue__
#define __gnu_awt_xlib_XEventQueue__

#pragma interface

#include <java/awt/EventQueue.h>
extern "Java"
{
  namespace gnu
  {
    namespace awt
    {
      namespace xlib
      {
          class XEventQueue;
      }
    }
    namespace gcj
    {
      namespace xlib
      {
          class Display;
      }
    }
  }
  namespace java
  {
    namespace awt
    {
        class AWTEvent;
    }
  }
}

class gnu::awt::xlib::XEventQueue : public ::java::awt::EventQueue
{

public:
  XEventQueue(::gnu::gcj::xlib::Display *);
  virtual ::java::awt::AWTEvent * getNextEvent();
public: // actually package-private
  ::gnu::gcj::xlib::Display * __attribute__((aligned(__alignof__( ::java::awt::EventQueue)))) display;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_awt_xlib_XEventQueue__
