
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_font_autofit_Edge__
#define __gnu_java_awt_font_autofit_Edge__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace font
        {
          namespace autofit
          {
              class Edge;
              class Segment;
              class Width;
          }
        }
      }
    }
  }
}

class gnu::java::awt::font::autofit::Edge : public ::java::lang::Object
{

public: // actually package-private
  Edge();
public:
  virtual ::java::lang::String * toString();
public: // actually package-private
  jint __attribute__((aligned(__alignof__( ::java::lang::Object)))) fpos;
  ::gnu::java::awt::font::autofit::Segment * first;
  ::gnu::java::awt::font::autofit::Segment * last;
  jint opos;
  ::gnu::java::awt::font::autofit::Edge * link;
  ::gnu::java::awt::font::autofit::Edge * serif;
  jint flags;
  jint dir;
  ::gnu::java::awt::font::autofit::Width * blueEdge;
  jint pos;
  jint scale;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_java_awt_font_autofit_Edge__
