
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_keyring_PasswordAuthenticatedEntry__
#define __gnu_javax_crypto_keyring_PasswordAuthenticatedEntry__

#pragma interface

#include <gnu/javax/crypto/keyring/MaskableEnvelopeEntry.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace keyring
        {
            class PasswordAuthenticatedEntry;
            class Properties;
        }
        namespace mac
        {
            class IMac;
        }
      }
    }
  }
}

class gnu::javax::crypto::keyring::PasswordAuthenticatedEntry : public ::gnu::javax::crypto::keyring::MaskableEnvelopeEntry
{

public:
  PasswordAuthenticatedEntry(::java::lang::String *, jint, ::gnu::javax::crypto::keyring::Properties *);
private:
  PasswordAuthenticatedEntry();
public:
  static ::gnu::javax::crypto::keyring::PasswordAuthenticatedEntry * decode(::java::io::DataInputStream *, JArray< jchar > *);
  static ::gnu::javax::crypto::keyring::PasswordAuthenticatedEntry * decode(::java::io::DataInputStream *);
  void verify(JArray< jchar > *);
  void authenticate(JArray< jchar > *);
  void encode(::java::io::DataOutputStream *, JArray< jchar > *);
public: // actually protected
  void encodePayload(::java::io::DataOutputStream *);
private:
  ::gnu::javax::crypto::mac::IMac * getMac(JArray< jchar > *);
  static ::java::util::logging::Logger * log;
public:
  static const jint TYPE = 3;
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_crypto_keyring_PasswordAuthenticatedEntry__
