
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_swing_text_html_css_FontSize__
#define __gnu_javax_swing_text_html_css_FontSize__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace swing
      {
        namespace text
        {
          namespace html
          {
            namespace css
            {
                class FontSize;
            }
          }
        }
      }
    }
  }
}

class gnu::javax::swing::text::html::css::FontSize : public ::java::lang::Object
{

public:
  FontSize(::java::lang::String *);
  virtual jint getValue(jint);
  virtual jint getValue();
private:
  jint mapValue();
  jint mapPoints();
  jint mapPixels();
  jint mapPercent(jint);
  jint mapEM(jint);
  jint mapSmaller(jint);
  jint mapLarger(jint);
  jint mapAbsolute();
public:
  virtual ::java::lang::String * toString();
private:
  jint mapRelative(jint);
public:
  virtual jboolean isRelative();
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object)))) value;
  jint size;
  jint sizeIndex;
  jboolean isRelative__;
public:
  static const jint DEFAULT_FONT_SIZE = 12;
private:
  static JArray< jdouble > * SCALE;
public: // actually package-private
  static jboolean $assertionsDisabled;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_swing_text_html_css_FontSize__
