
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_key_BaseKeyAgreementParty__
#define __gnu_javax_crypto_key_BaseKeyAgreementParty__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace prng
        {
            class IRandom;
        }
        namespace util
        {
            class PRNG;
        }
      }
    }
    namespace javax
    {
      namespace crypto
      {
        namespace key
        {
            class BaseKeyAgreementParty;
            class IncomingMessage;
            class OutgoingMessage;
        }
      }
    }
  }
  namespace java
  {
    namespace math
    {
        class BigInteger;
    }
    namespace security
    {
        class SecureRandom;
    }
  }
}

class gnu::javax::crypto::key::BaseKeyAgreementParty : public ::java::lang::Object
{

public: // actually protected
  BaseKeyAgreementParty(::java::lang::String *);
public:
  virtual ::java::lang::String * name();
  virtual void init(::java::util::Map *);
  virtual ::gnu::javax::crypto::key::OutgoingMessage * processMessage(::gnu::javax::crypto::key::IncomingMessage *);
  virtual jboolean isComplete();
  virtual JArray< jbyte > * getSharedSecret();
  virtual void reset();
public: // actually protected
  virtual void engineInit(::java::util::Map *) = 0;
  virtual ::gnu::javax::crypto::key::OutgoingMessage * engineProcessMessage(::gnu::javax::crypto::key::IncomingMessage *) = 0;
  virtual JArray< jbyte > * engineSharedSecret() = 0;
  virtual void engineReset() = 0;
  virtual void nextRandomBytes(JArray< jbyte > *);
private:
  ::gnu::java::security::util::PRNG * getDefaultPRNG();
public: // actually protected
  static ::java::math::BigInteger * TWO;
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object)))) name__;
  jboolean initialised;
  jint step;
  jboolean complete;
  ::java::security::SecureRandom * rnd;
  ::gnu::java::security::prng::IRandom * irnd;
private:
  ::gnu::java::security::util::PRNG * prng;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_crypto_key_BaseKeyAgreementParty__
