
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_xml_validation_datatype_GDayType$GDay__
#define __gnu_xml_validation_datatype_GDayType$GDay__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace xml
    {
      namespace validation
      {
        namespace datatype
        {
            class GDayType$GDay;
        }
      }
    }
  }
}

class gnu::xml::validation::datatype::GDayType$GDay : public ::java::lang::Object
{

public: // actually package-private
  GDayType$GDay();
public:
  virtual jint hashCode();
  virtual jboolean equals(::java::lang::Object *);
  virtual jint compareTo(::java::lang::Object *);
public: // actually package-private
  jint __attribute__((aligned(__alignof__( ::java::lang::Object)))) day;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_xml_validation_datatype_GDayType$GDay__
