
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_xml_xpath_XPathParser$yyInput__
#define __gnu_xml_xpath_XPathParser$yyInput__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace xml
    {
      namespace xpath
      {
          class XPathParser$yyInput;
      }
    }
  }
}

class gnu::xml::xpath::XPathParser$yyInput : public ::java::lang::Object
{

public:
  virtual jboolean advance() = 0;
  virtual jint token() = 0;
  virtual ::java::lang::Object * value() = 0;
  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif // __gnu_xml_xpath_XPathParser$yyInput__
