
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_xml_util_SAXNullTransformerFactory$ListenerAdapter__
#define __gnu_xml_util_SAXNullTransformerFactory$ListenerAdapter__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace xml
    {
      namespace util
      {
          class SAXNullTransformerFactory$ListenerAdapter;
          class SAXNullTransformerFactory$NullTransformer;
      }
    }
  }
  namespace javax
  {
    namespace xml
    {
      namespace transform
      {
          class TransformerException;
      }
    }
  }
  namespace org
  {
    namespace xml
    {
      namespace sax
      {
          class SAXParseException;
      }
    }
  }
}

class gnu::xml::util::SAXNullTransformerFactory$ListenerAdapter : public ::java::lang::Object
{

public: // actually package-private
  SAXNullTransformerFactory$ListenerAdapter(::gnu::xml::util::SAXNullTransformerFactory$NullTransformer *);
private:
  ::javax::xml::transform::TransformerException * map(::org::xml::sax::SAXParseException *);
public:
  virtual void error(::org::xml::sax::SAXParseException *);
  virtual void fatalError(::org::xml::sax::SAXParseException *);
  virtual void warning(::org::xml::sax::SAXParseException *);
public: // actually package-private
  ::gnu::xml::util::SAXNullTransformerFactory$NullTransformer * __attribute__((aligned(__alignof__( ::java::lang::Object)))) transformer;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_xml_util_SAXNullTransformerFactory$ListenerAdapter__
