
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_xml_aelfred2_XmlParser$ElementDecl__
#define __gnu_xml_aelfred2_XmlParser$ElementDecl__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace xml
    {
      namespace aelfred2
      {
          class XmlParser$ElementDecl;
      }
    }
  }
}

class gnu::xml::aelfred2::XmlParser$ElementDecl : public ::java::lang::Object
{

public: // actually package-private
  XmlParser$ElementDecl();
  jint __attribute__((aligned(__alignof__( ::java::lang::Object)))) contentType;
  ::java::lang::String * contentModel;
  ::java::util::HashMap * attributes;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_xml_aelfred2_XmlParser$ElementDecl__
