
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_CORBA_Interceptor_IORInterceptors__
#define __gnu_CORBA_Interceptor_IORInterceptors__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace CORBA
    {
      namespace Interceptor
      {
          class IORInterceptors;
          class Registrator;
      }
    }
  }
  namespace org
  {
    namespace omg
    {
      namespace PortableInterceptor
      {
          class IORInfo;
          class IORInterceptor;
          class ObjectReferenceTemplate;
      }
    }
  }
}

class gnu::CORBA::Interceptor::IORInterceptors : public ::java::lang::Object
{

public:
  IORInterceptors(::gnu::CORBA::Interceptor::Registrator *);
  virtual void establish_components(::org::omg::PortableInterceptor::IORInfo *);
  virtual void destroy();
  virtual ::java::lang::String * name();
  virtual void adapter_manager_state_changed(jint, jshort);
  virtual void adapter_state_changed(JArray< ::org::omg::PortableInterceptor::ObjectReferenceTemplate * > *, jshort);
  virtual void components_established(::org::omg::PortableInterceptor::IORInfo *);
private:
  JArray< ::org::omg::PortableInterceptor::IORInterceptor * > * __attribute__((aligned(__alignof__( ::java::lang::Object)))) interceptors;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_CORBA_Interceptor_IORInterceptors__
