
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_peer_qt_QtRepaintThread__
#define __gnu_java_awt_peer_qt_QtRepaintThread__

#pragma interface

#include <java/lang/Thread.h>
extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace peer
        {
          namespace qt
          {
              class QtComponentPeer;
              class QtRepaintThread;
              class QtRepaintThread$RepaintComponent;
          }
        }
      }
    }
  }
}

class gnu::java::awt::peer::qt::QtRepaintThread : public ::java::lang::Thread
{

public:
  QtRepaintThread();
  virtual void run();
  virtual void queueComponent(::gnu::java::awt::peer::qt::QtComponentPeer *);
  virtual void queueComponent(::gnu::java::awt::peer::qt::QtComponentPeer *, jint, jint, jint, jint);
public: // actually package-private
  ::gnu::java::awt::peer::qt::QtRepaintThread$RepaintComponent * __attribute__((aligned(__alignof__( ::java::lang::Thread)))) component;
  jboolean busy;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_java_awt_peer_qt_QtRepaintThread__
