
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_xml_aelfred2_XmlParser$EntityInfo__
#define __gnu_xml_aelfred2_XmlParser$EntityInfo__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace xml
    {
      namespace aelfred2
      {
          class XmlParser$EntityInfo;
          class XmlParser$ExternalIdentifiers;
      }
    }
  }
}

class gnu::xml::aelfred2::XmlParser$EntityInfo : public ::java::lang::Object
{

public: // actually package-private
  XmlParser$EntityInfo();
  jint __attribute__((aligned(__alignof__( ::java::lang::Object)))) type;
  ::gnu::xml::aelfred2::XmlParser$ExternalIdentifiers * ids;
  ::java::lang::String * value;
  ::java::lang::String * notationName;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_xml_aelfred2_XmlParser$EntityInfo__
