
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_CORBA_CDR_gnuRuntime$Redirection__
#define __gnu_CORBA_CDR_gnuRuntime$Redirection__

#pragma interface

#include <gnu/CORBA/CDR/gnuRuntime$Entry.h>
extern "Java"
{
  namespace gnu
  {
    namespace CORBA
    {
      namespace CDR
      {
          class gnuRuntime$Redirection;
      }
    }
  }
}

class gnu::CORBA::CDR::gnuRuntime$Redirection : public ::gnu::CORBA::CDR::gnuRuntime$Entry
{

public: // actually package-private
  gnuRuntime$Redirection();
public:
  virtual ::java::lang::String * toString();
  static ::java::lang::Class class$;
};

#endif // __gnu_CORBA_CDR_gnuRuntime$Redirection__
