
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_convert_Input_8859_1__
#define __gnu_gcj_convert_Input_8859_1__

#pragma interface

#include <gnu/gcj/convert/BytesToUnicode.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace convert
      {
          class Input_8859_1;
      }
    }
  }
}

class gnu::gcj::convert::Input_8859_1 : public ::gnu::gcj::convert::BytesToUnicode
{

public:
  Input_8859_1();
  virtual ::java::lang::String * getName();
  virtual jint read(JArray< jchar > *, jint, jint);
  static ::java::lang::Class class$;
};

#endif // __gnu_gcj_convert_Input_8859_1__
