
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_classpath_jdwp_Jdwp$1__
#define __gnu_classpath_jdwp_Jdwp$1__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace classpath
    {
      namespace jdwp
      {
          class Jdwp;
          class Jdwp$1;
      }
    }
  }
}

class gnu::classpath::jdwp::Jdwp$1 : public ::java::lang::Object
{

public: // actually package-private
  Jdwp$1(::gnu::classpath::jdwp::Jdwp *);
public:
  void run();
public: // actually package-private
  ::gnu::classpath::jdwp::Jdwp * __attribute__((aligned(__alignof__( ::java::lang::Object)))) this$0;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_classpath_jdwp_Jdwp$1__
