
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_xml_validation_relaxng_GrammarException__
#define __gnu_xml_validation_relaxng_GrammarException__

#pragma interface

#include <java/io/IOException.h>
extern "Java"
{
  namespace gnu
  {
    namespace xml
    {
      namespace validation
      {
        namespace relaxng
        {
            class GrammarException;
        }
      }
    }
  }
}

class gnu::xml::validation::relaxng::GrammarException : public ::java::io::IOException
{

public: // actually package-private
  GrammarException(::java::lang::String *);
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_xml_validation_relaxng_GrammarException__
