
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_jvmti_Location__
#define __gnu_gcj_jvmti_Location__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace jvmti
      {
          class Location;
      }
    }
  }
}

class gnu::gcj::jvmti::Location : public ::java::lang::Object
{

public:
  Location(jlong, jlong);
  virtual jint hashCode();
  virtual jboolean equals(::java::lang::Object *);
  virtual ::java::lang::String * toString();
private:
  jlong __attribute__((aligned(__alignof__( ::java::lang::Object)))) method;
  jlong location;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_gcj_jvmti_Location__
