
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_peer_swing_SwingTextAreaPeer$1__
#define __gnu_java_awt_peer_swing_SwingTextAreaPeer$1__

#pragma interface

#include <javax/swing/JViewport.h>
extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace peer
        {
          namespace swing
          {
              class SwingTextAreaPeer;
              class SwingTextAreaPeer$1;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
        class Image;
    }
  }
}

class gnu::java::awt::peer::swing::SwingTextAreaPeer$1 : public ::javax::swing::JViewport
{

public: // actually package-private
  SwingTextAreaPeer$1(::gnu::java::awt::peer::swing::SwingTextAreaPeer *);
public:
  ::java::awt::Image * createImage(jint, jint);
public: // actually package-private
  ::gnu::java::awt::peer::swing::SwingTextAreaPeer * __attribute__((aligned(__alignof__( ::javax::swing::JViewport)))) this$0;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_java_awt_peer_swing_SwingTextAreaPeer$1__
