
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_xlib_XAnyEvent__
#define __gnu_gcj_xlib_XAnyEvent__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
        class RawData;
      namespace xlib
      {
          class Display;
          class Window;
          class XAnyEvent;
      }
    }
  }
}

class gnu::gcj::xlib::XAnyEvent : public ::java::lang::Object
{

public:
  XAnyEvent(::gnu::gcj::xlib::Display *);
private:
  void init();
public: // actually protected
  void finalize();
public:
  jboolean loadNext(jboolean);
  void interrupt();
  jint getType();
  void setType(jint);
  ::gnu::gcj::xlib::Window * getWindow();
  void setWindow(::gnu::gcj::xlib::Window *);
  jlong getSerial();
  void send(::gnu::gcj::xlib::Window *, jboolean, jlong);
  ::java::lang::String * toString();
  static const jint TYPE_KEY_PRESS = 2;
  static const jint TYPE_KEY_RELEASE = 3;
  static const jint TYPE_BUTTON_PRESS = 4;
  static const jint TYPE_BUTTON_RELEASE = 5;
  static const jint TYPE_MOTION_NOTIFY = 6;
  static const jint TYPE_ENTER_NOTIFY = 7;
  static const jint TYPE_LEAVE_NOTIFY = 8;
  static const jint TYPE_FOCUS_IN = 9;
  static const jint TYPE_FOCUS_OUT = 10;
  static const jint TYPE_KEYMAP_NOTIFY = 11;
  static const jint TYPE_EXPOSE = 12;
  static const jint TYPE_GRAPHICS_EXPOSE = 13;
  static const jint TYPE_NO_EXPOSE = 14;
  static const jint TYPE_VISIBILITY_NOTIFY = 15;
  static const jint TYPE_CREATE_NOTIFY = 16;
  static const jint TYPE_DESTROY_NOTIFY = 17;
  static const jint TYPE_UNMAP_NOTIFY = 18;
  static const jint TYPE_MAP_NOTIFY = 19;
  static const jint TYPE_MAP_REQUEST = 20;
  static const jint TYPE_REPARENT_NOTIFY = 21;
  static const jint TYPE_CONFIGURE_NOTIFY = 22;
  static const jint TYPE_CONFIGURE_REQUEST = 23;
  static const jint TYPE_GRAVITY_NOTIFY = 24;
  static const jint TYPE_RESIZE_REQUEST = 25;
  static const jint TYPE_CIRCULATE_NOTIFY = 26;
  static const jint TYPE_CIRCULATE_REQUEST = 27;
  static const jint TYPE_PROPERTY_NOTIFY = 28;
  static const jint TYPE_SELECTION_CLEAR = 29;
  static const jint TYPE_SELECTION_REQUEST = 30;
  static const jint TYPE_SELECTION_NOTIFY = 31;
  static const jint TYPE_COLORMAP_NOTIFY = 32;
  static const jint TYPE_CLIENT_MESSAGE = 33;
  static const jint TYPE_MAPPING_NOTIFY = 34;
  static const jlong MASK_SUBSTRUCTURE_NOTIFY = 524288LL;
  static const jlong MASK_SUBSTRUCTURE_REDIRECT = 1048576LL;
public: // actually package-private
  ::gnu::gcj::RawData * __attribute__((aligned(__alignof__( ::java::lang::Object)))) pipefds;
  ::gnu::gcj::RawData * structure;
  ::gnu::gcj::xlib::Display * display;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_gcj_xlib_XAnyEvent__
