
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_prng_CSPRNG$Spinner__
#define __gnu_javax_crypto_prng_CSPRNG$Spinner__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace prng
        {
            class CSPRNG$Spinner;
        }
      }
    }
  }
}

class gnu::javax::crypto::prng::CSPRNG$Spinner : public ::java::lang::Object
{

  CSPRNG$Spinner();
public:
  virtual void run();
public: // actually package-private
  CSPRNG$Spinner(::gnu::javax::crypto::prng::CSPRNG$Spinner *);
public: // actually protected
  jbyte __attribute__((aligned(__alignof__( ::java::lang::Object)))) counter;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_crypto_prng_CSPRNG$Spinner__
