
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_dnd_peer_gtk_GtkDropTargetPeer__
#define __gnu_java_awt_dnd_peer_gtk_GtkDropTargetPeer__

#pragma interface

#include <gnu/java/awt/peer/gtk/GtkGenericPeer.h>
extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace dnd
        {
          namespace peer
          {
            namespace gtk
            {
                class GtkDropTargetPeer;
            }
          }
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
      namespace dnd
      {
          class DropTarget;
      }
    }
  }
}

class gnu::java::awt::dnd::peer::gtk::GtkDropTargetPeer : public ::gnu::java::awt::peer::gtk::GtkGenericPeer
{

public:
  GtkDropTargetPeer();
  virtual void addDropTarget(::java::awt::dnd::DropTarget *);
  virtual void removeDropTarget(::java::awt::dnd::DropTarget *);
  static ::java::lang::Class class$;
};

#endif // __gnu_java_awt_dnd_peer_gtk_GtkDropTargetPeer__
