
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_peer_qt_QtImageGraphics__
#define __gnu_java_awt_peer_qt_QtImageGraphics__

#pragma interface

#include <gnu/java/awt/peer/qt/QtGraphics.h>
extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace peer
        {
          namespace qt
          {
              class QtImageGraphics;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
        class Graphics;
        class GraphicsConfiguration;
        class Image;
    }
  }
}

class gnu::java::awt::peer::qt::QtImageGraphics : public ::gnu::java::awt::peer::qt::QtGraphics
{

public:
  QtImageGraphics(::java::awt::Image *);
public: // actually package-private
  QtImageGraphics(::gnu::java::awt::peer::qt::QtImageGraphics *);
public:
  virtual void dispose();
  virtual ::java::awt::Graphics * create();
  virtual void copyArea(jint, jint, jint, jint, jint, jint);
  virtual ::java::awt::GraphicsConfiguration * getDeviceConfiguration();
public: // actually package-private
  ::java::awt::Image * __attribute__((aligned(__alignof__( ::gnu::java::awt::peer::qt::QtGraphics)))) parentImage;
  ::java::util::Stack * owners;
  ::gnu::java::awt::peer::qt::QtImageGraphics * topParent;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_java_awt_peer_qt_QtImageGraphics__
