
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_security_auth_callback_GnuCallbacks$1__
#define __gnu_javax_security_auth_callback_GnuCallbacks$1__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace security
      {
        namespace auth
        {
          namespace callback
          {
              class GnuCallbacks;
              class GnuCallbacks$1;
          }
        }
      }
    }
  }
}

class gnu::javax::security::auth::callback::GnuCallbacks$1 : public ::java::lang::Object
{

public: // actually package-private
  GnuCallbacks$1(::gnu::javax::security::auth::callback::GnuCallbacks *);
public:
  ::java::lang::Object * run();
public: // actually package-private
  ::gnu::javax::security::auth::callback::GnuCallbacks * __attribute__((aligned(__alignof__( ::java::lang::Object)))) this$0;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_security_auth_callback_GnuCallbacks$1__
