
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_util_regex_RE$NamedProperty__
#define __gnu_java_util_regex_RE$NamedProperty__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace util
      {
        namespace regex
        {
            class RE$NamedProperty;
        }
      }
    }
  }
}

class gnu::java::util::regex::RE$NamedProperty : public ::java::lang::Object
{

  RE$NamedProperty();
public: // actually package-private
  RE$NamedProperty(::gnu::java::util::regex::RE$NamedProperty *);
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object)))) name;
  jboolean negate;
  jint len;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_java_util_regex_RE$NamedProperty__
