
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_ServerHandshake$CertLoader__
#define __gnu_javax_net_ssl_provider_ServerHandshake$CertLoader__

#pragma interface

#include <gnu/javax/net/ssl/provider/DelegatedTask.h>
extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
              class ServerHandshake;
              class ServerHandshake$CertLoader;
          }
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::ServerHandshake$CertLoader : public ::gnu::javax::net::ssl::provider::DelegatedTask
{

public: // actually package-private
  ServerHandshake$CertLoader(::gnu::javax::net::ssl::provider::ServerHandshake *);
public:
  virtual void implRun();
public: // actually package-private
  ::gnu::javax::net::ssl::provider::ServerHandshake * __attribute__((aligned(__alignof__( ::gnu::javax::net::ssl::provider::DelegatedTask)))) this$0;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_net_ssl_provider_ServerHandshake$CertLoader__
