
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_X500PrincipalList__
#define __gnu_javax_net_ssl_provider_X500PrincipalList__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
              class X500PrincipalList;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace nio
    {
        class ByteBuffer;
    }
  }
  namespace javax
  {
    namespace security
    {
      namespace auth
      {
        namespace x500
        {
            class X500Principal;
        }
      }
    }
  }
}

class gnu::javax::net::ssl::provider::X500PrincipalList : public ::java::lang::Object
{

public:
  X500PrincipalList(::java::nio::ByteBuffer *);
  jint size();
  jint count();
  ::javax::security::auth::x500::X500Principal * get(jint);
  void put(jint, ::javax::security::auth::x500::X500Principal *);
  void put(jint, JArray< jbyte > *);
  void setSize(jint, jint);
  ::java::lang::String * toString();
  ::java::lang::String * toString(::java::lang::String *);
  jboolean equals(::java::lang::Object *);
  ::java::util::Iterator * iterator();
public: // actually package-private
  static jint access$0(::gnu::javax::net::ssl::provider::X500PrincipalList *);
private:
  ::java::nio::ByteBuffer * __attribute__((aligned(__alignof__( ::java::lang::Object)))) buffer;
  jint modCount;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_net_ssl_provider_X500PrincipalList__
