
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_keyring_PasswordProtectedEntry__
#define __gnu_javax_crypto_keyring_PasswordProtectedEntry__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace keyring
        {
            class PasswordProtectedEntry;
        }
      }
    }
  }
}

class gnu::javax::crypto::keyring::PasswordProtectedEntry : public ::java::lang::Object
{

public:
  virtual void encode(::java::io::DataOutputStream *, JArray< jchar > *) = 0;
  static ::java::lang::Integer * ITERATION_COUNT;
  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif // __gnu_javax_crypto_keyring_PasswordProtectedEntry__
