
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_io_SimpleSHSStream__
#define __gnu_gcj_io_SimpleSHSStream__

#pragma interface

#include <java/io/DataOutputStream.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace io
      {
          class SimpleSHSStream;
      }
    }
  }
}

class gnu::gcj::io::SimpleSHSStream : public ::java::io::DataOutputStream
{

public: // actually package-private
  static JArray< jbyte > * shsFinal(JArray< jbyte > *);
  static void shsUpdate(JArray< jbyte > *, JArray< jbyte > *, jint);
  static JArray< jbyte > * shsInit();
private:
  void update(jbyte);
public:
  virtual void write(jint);
  virtual void write(JArray< jbyte > *, jint, jint);
  virtual JArray< jbyte > * digest();
  SimpleSHSStream(::java::io::OutputStream *);
public: // actually package-private
  jint __attribute__((aligned(__alignof__( ::java::io::DataOutputStream)))) counter;
  const jint SHS_BLOCKSIZE;
  const jint SHS_DIGESTSIZE;
  JArray< jbyte > * buf;
  JArray< jbyte > * shs_info;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_gcj_io_SimpleSHSStream__
