
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_sound_midi_file_MidiDataInputStream__
#define __gnu_javax_sound_midi_file_MidiDataInputStream__

#pragma interface

#include <java/io/DataInputStream.h>
extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace sound
      {
        namespace midi
        {
          namespace file
          {
              class MidiDataInputStream;
          }
        }
      }
    }
  }
}

class gnu::javax::sound::midi::file::MidiDataInputStream : public ::java::io::DataInputStream
{

public:
  MidiDataInputStream(::java::io::InputStream *);
  virtual jint readVariableLengthInt();
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_sound_midi_file_MidiDataInputStream__
