
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_util_UtilPermission__
#define __gnu_gcj_util_UtilPermission__

#pragma interface

#include <java/security/BasicPermission.h>
extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace util
      {
          class UtilPermission;
      }
    }
  }
}

class gnu::gcj::util::UtilPermission : public ::java::security::BasicPermission
{

public:
  UtilPermission(::java::lang::String *);
  static ::java::lang::Class class$;
};

#endif // __gnu_gcj_util_UtilPermission__
