
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_sound_sampled_gstreamer_lines_GstDataLine$State__
#define __gnu_javax_sound_sampled_gstreamer_lines_GstDataLine$State__

#pragma interface

#include <java/lang/Enum.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace sound
      {
        namespace sampled
        {
          namespace gstreamer
          {
            namespace lines
            {
                class GstDataLine$State;
            }
          }
        }
      }
    }
  }
}

class gnu::javax::sound::sampled::gstreamer::lines::GstDataLine$State : public ::java::lang::Enum
{

  GstDataLine$State(::java::lang::String *, jint);
public:
  static JArray< ::gnu::javax::sound::sampled::gstreamer::lines::GstDataLine$State * > * values();
  static ::gnu::javax::sound::sampled::gstreamer::lines::GstDataLine$State * valueOf(::java::lang::String *);
  static ::gnu::javax::sound::sampled::gstreamer::lines::GstDataLine$State * PLAY;
  static ::gnu::javax::sound::sampled::gstreamer::lines::GstDataLine$State * PAUSE;
  static ::gnu::javax::sound::sampled::gstreamer::lines::GstDataLine$State * STOP;
private:
  static JArray< ::gnu::javax::sound::sampled::gstreamer::lines::GstDataLine$State * > * ENUM$VALUES;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_sound_sampled_gstreamer_lines_GstDataLine$State__
