
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_CORBA_DynAn_gnuDynFixed__
#define __gnu_CORBA_DynAn_gnuDynFixed__

#pragma interface

#include <gnu/CORBA/DynAn/UndivideableAny.h>
extern "Java"
{
  namespace gnu
  {
    namespace CORBA
    {
      namespace DynAn
      {
          class gnuDynAnyFactory;
          class gnuDynFixed;
      }
    }
  }
  namespace java
  {
    namespace math
    {
        class BigDecimal;
    }
  }
  namespace org
  {
    namespace omg
    {
      namespace CORBA
      {
          class Any;
          class ORB;
          class TypeCode;
      }
      namespace DynamicAny
      {
          class DynAny;
      }
    }
  }
}

class gnu::CORBA::DynAn::gnuDynFixed : public ::gnu::CORBA::DynAn::UndivideableAny
{

public:
  gnuDynFixed(::org::omg::CORBA::TypeCode *, ::org::omg::CORBA::TypeCode *, ::gnu::CORBA::DynAn::gnuDynAnyFactory *, ::org::omg::CORBA::ORB *);
  gnuDynFixed(::gnu::CORBA::DynAn::gnuDynFixed *);
  virtual ::java::lang::String * get_value();
  virtual jboolean set_value(::java::lang::String *);
  virtual void assign(::org::omg::DynamicAny::DynAny *);
  virtual ::org::omg::DynamicAny::DynAny * copy();
  virtual jboolean equal(::org::omg::DynamicAny::DynAny *);
  virtual void from_any(::org::omg::CORBA::Any *);
  virtual ::org::omg::CORBA::Any * to_any();
private:
  static const jlong serialVersionUID = 1LL;
public: // actually package-private
  static ::java::math::BigDecimal * ZERO;
  ::java::math::BigDecimal * __attribute__((aligned(__alignof__( ::gnu::CORBA::DynAn::UndivideableAny)))) value;
  jint scale;
  jint digits;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_CORBA_DynAn_gnuDynFixed__
