
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_dnd_peer_gtk_GtkDragSourceContextPeer__
#define __gnu_java_awt_dnd_peer_gtk_GtkDragSourceContextPeer__

#pragma interface

#include <gnu/java/awt/peer/gtk/GtkGenericPeer.h>
extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        namespace dnd
        {
          namespace peer
          {
            namespace gtk
            {
                class GtkDragSourceContextPeer;
                class GtkDropTargetContextPeer;
            }
          }
        }
      }
    }
  }
  namespace java
  {
    namespace awt
    {
        class Component;
        class Cursor;
        class Image;
        class Point;
      namespace dnd
      {
          class DragGestureEvent;
          class DragSourceContext;
      }
      namespace peer
      {
          class ComponentPeer;
      }
    }
  }
}

class gnu::java::awt::dnd::peer::gtk::GtkDragSourceContextPeer : public ::gnu::java::awt::peer::gtk::GtkGenericPeer
{

public: // actually package-private
  virtual void nativeStartDrag(::java::awt::Image *, jint, jint, jint, ::java::lang::String *);
  virtual void connectSignals(::java::awt::peer::ComponentPeer *);
  virtual void create(::java::awt::peer::ComponentPeer *);
  virtual void nativeSetCursor(jint);
  virtual void setTarget(::gnu::java::awt::dnd::peer::gtk::GtkDropTargetContextPeer *);
public:
  GtkDragSourceContextPeer(::java::awt::dnd::DragGestureEvent *);
public: // actually package-private
  virtual ::java::awt::peer::ComponentPeer * getComponentPeer(::java::awt::Component *);
public:
  virtual void startDrag(::java::awt::dnd::DragSourceContext *, ::java::awt::Cursor *, ::java::awt::Image *, ::java::awt::Point *);
  virtual ::java::awt::Cursor * getCursor();
  virtual void setCursor(::java::awt::Cursor *);
  virtual void transferablesFlavorsChanged();
  virtual void dragEnter(jint, jint);
  virtual void dragExit(jint, jint, jint);
  virtual void dragDropEnd(jint, jboolean, jint, jint);
  virtual void dragMouseMoved(jint, jint);
  virtual void dragOver(jint, jint);
  virtual void dragActionChanged(jint, jint);
private:
  ::java::awt::peer::ComponentPeer * __attribute__((aligned(__alignof__( ::gnu::java::awt::peer::gtk::GtkGenericPeer)))) peer;
  ::java::awt::Cursor * cursor;
  ::java::awt::dnd::DragSourceContext * context;
public:
  static ::java::awt::Component * target;
  static ::java::lang::Class class$;
};

#endif // __gnu_java_awt_dnd_peer_gtk_GtkDragSourceContextPeer__
