
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_print_ipp_IppDelimiterTag__
#define __gnu_javax_print_ipp_IppDelimiterTag__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace print
      {
        namespace ipp
        {
            class IppDelimiterTag;
        }
      }
    }
  }
}

class gnu::javax::print::ipp::IppDelimiterTag : public ::java::lang::Object
{

  IppDelimiterTag();
public:
  static jboolean isDelimiterTag(jbyte);
  static const jbyte OPERATION_ATTRIBUTES_TAG = 1;
  static const jbyte JOB_ATTRIBUTES_TAG = 2;
  static const jbyte END_OF_ATTRIBUTES_TAG = 3;
  static const jbyte PRINTER_ATTRIBUTES_TAG = 4;
  static const jbyte UNSUPPORTED_ATTRIBUTES_TAG = 5;
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_print_ipp_IppDelimiterTag__
