
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_xml_util_XCat$Catalog__
#define __gnu_xml_util_XCat$Catalog__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace xml
    {
      namespace util
      {
          class XCat$Catalog;
      }
    }
  }
  namespace org
  {
    namespace xml
    {
      namespace sax
      {
          class ErrorHandler;
          class InputSource;
      }
    }
  }
}

class gnu::xml::util::XCat$Catalog : public ::java::lang::Object
{

public: // actually package-private
  XCat$Catalog();
private:
  ::org::xml::sax::InputSource * locatePublicId(::java::lang::String *);
  ::org::xml::sax::InputSource * mapURI(::java::lang::String *, ::java::util::Hashtable *, ::java::util::Hashtable *, ::java::util::Hashtable *);
public:
  virtual ::org::xml::sax::InputSource * resolve(jboolean, ::java::lang::String *, ::java::lang::String *);
  virtual ::org::xml::sax::InputSource * resolveURI(::java::lang::String *);
  virtual ::org::xml::sax::InputSource * getExternalSubset(::java::lang::String *);
private:
  ::gnu::xml::util::XCat$Catalog * getNext(jint);
  ::org::xml::sax::InputSource * checkDelegations(::java::util::Hashtable *, ::java::lang::String *, ::java::lang::String *, ::java::lang::String *);
public: // actually package-private
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object)))) catalogURI;
  ::org::xml::sax::ErrorHandler * eh;
  jboolean unified;
  ::java::lang::String * parserClass;
  jboolean hasPreference;
  jboolean usingPublic;
  ::java::util::Hashtable * publicIds;
  ::java::util::Hashtable * publicDelegations;
  ::java::util::Hashtable * systemIds;
  ::java::util::Hashtable * systemRewrites;
  ::java::util::Hashtable * systemDelegations;
  ::java::util::Hashtable * uris;
  ::java::util::Hashtable * uriRewrites;
  ::java::util::Hashtable * uriDelegations;
  ::java::util::Hashtable * doctypes;
  ::java::util::Vector * next;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_xml_util_XCat$Catalog__
