
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_x509_X509CRLSelectorImpl__
#define __gnu_java_security_x509_X509CRLSelectorImpl__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace x509
        {
            class X509CRLSelectorImpl;
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
        class Principal;
      namespace cert
      {
          class CRL;
      }
    }
  }
}

class gnu::java::security::x509::X509CRLSelectorImpl : public ::java::lang::Object
{

public:
  X509CRLSelectorImpl();
  virtual void addIssuerName(JArray< jbyte > *);
  virtual void addIssuerName(::java::lang::String *);
  virtual void addIssuerName(::java::security::Principal *);
  virtual ::java::util::Collection * getIssuerNames();
  virtual ::java::lang::Object * clone();
  virtual jboolean match(::java::security::cert::CRL *);
private:
  ::java::util::Set * __attribute__((aligned(__alignof__( ::java::lang::Object)))) issuerNames;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_java_security_x509_X509CRLSelectorImpl__
