
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_awt_xlib_XGraphicsDevice__
#define __gnu_awt_xlib_XGraphicsDevice__

#pragma interface

#include <java/awt/GraphicsDevice.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace awt
    {
      namespace xlib
      {
          class XGraphicsDevice;
          class XToolkit;
      }
    }
  }
  namespace java
  {
    namespace awt
    {
        class GraphicsConfiguration;
    }
  }
}

class gnu::awt::xlib::XGraphicsDevice : public ::java::awt::GraphicsDevice
{

public:
  virtual jint getType();
  XGraphicsDevice(jint, ::gnu::awt::xlib::XToolkit *);
  virtual ::java::lang::String * getIDstring();
  virtual JArray< ::java::awt::GraphicsConfiguration * > * getConfigurations();
  virtual ::java::awt::GraphicsConfiguration * getDefaultConfiguration();
  virtual jboolean isDisplayChangeSupported();
  virtual jboolean isFullScreenSupported();
private:
  jint __attribute__((aligned(__alignof__( ::java::awt::GraphicsDevice)))) id;
  ::java::lang::String * IDstring;
  JArray< ::java::awt::GraphicsConfiguration * > * configs;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_awt_xlib_XGraphicsDevice__
