
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_imageio_jpeg_DCT__
#define __gnu_javax_imageio_jpeg_DCT__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace imageio
      {
        namespace jpeg
        {
            class DCT;
        }
      }
    }
  }
}

class gnu::javax::imageio::jpeg::DCT : public ::java::lang::Object
{

public:
  DCT();
  static jdouble C(jint);
private:
  void initMatrix();
public:
  static JArray< JArray< jdouble > * > * slow_idct(JArray< JArray< jdouble > * > *);
  static JArray< JArray< jfloat > * > * slow_fdct(JArray< JArray< jfloat > * > *);
  virtual JArray< JArray< jfloat > * > * fast_fdct(JArray< JArray< jfloat > * > *);
  virtual JArray< JArray< jdouble > * > * fast_idct(JArray< JArray< jdouble > * > *);
  virtual JArray< JArray< jdouble > * > * idj_fast_fdct(JArray< JArray< jfloat > * > *);
  JArray< JArray< jdouble > * > * __attribute__((aligned(__alignof__( ::java::lang::Object)))) c;
  JArray< JArray< jdouble > * > * cT;
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_imageio_jpeg_DCT__
