
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_net_ssl_provider_Util$WrappedBuffer__
#define __gnu_javax_net_ssl_provider_Util$WrappedBuffer__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace net
      {
        namespace ssl
        {
          namespace provider
          {
              class Util$WrappedBuffer;
          }
        }
      }
    }
  }
  namespace java
  {
    namespace nio
    {
        class ByteBuffer;
    }
  }
}

class gnu::javax::net::ssl::provider::Util$WrappedBuffer : public ::java::lang::Object
{

public: // actually package-private
  Util$WrappedBuffer(::java::nio::ByteBuffer *, ::java::lang::String *);
public:
  virtual ::java::lang::String * toString();
private:
  ::java::nio::ByteBuffer * __attribute__((aligned(__alignof__( ::java::lang::Object)))) buffer;
  ::java::lang::String * prefix;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_net_ssl_provider_Util$WrappedBuffer__
