
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_awt_xlib_XPanelPeer__
#define __gnu_awt_xlib_XPanelPeer__

#pragma interface

#include <gnu/awt/xlib/XCanvasPeer.h>
extern "Java"
{
  namespace gnu
  {
    namespace awt
    {
      namespace xlib
      {
          class XPanelPeer;
      }
    }
  }
  namespace java
  {
    namespace awt
    {
        class Insets;
        class Panel;
    }
  }
}

class gnu::awt::xlib::XPanelPeer : public ::gnu::awt::xlib::XCanvasPeer
{

public:
  XPanelPeer(::java::awt::Panel *);
  virtual ::java::awt::Insets * getInsets();
  virtual ::java::awt::Insets * insets();
  virtual void beginValidate();
  virtual void endValidate();
  virtual void beginLayout();
  virtual void endLayout();
  virtual jboolean isPaintPending();
public: // actually package-private
  static ::java::awt::Insets * INSETS_0_PROTOTYPE;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_awt_xlib_XPanelPeer__
