
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_xml_pipeline_XIncludeFilter$Scrubber__
#define __gnu_xml_pipeline_XIncludeFilter$Scrubber__

#pragma interface

#include <gnu/xml/pipeline/EventFilter.h>
extern "Java"
{
  namespace gnu
  {
    namespace xml
    {
      namespace pipeline
      {
          class EventFilter;
          class XIncludeFilter;
          class XIncludeFilter$Scrubber;
      }
    }
  }
  namespace org
  {
    namespace xml
    {
      namespace sax
      {
          class Locator;
      }
    }
  }
}

class gnu::xml::pipeline::XIncludeFilter$Scrubber : public ::gnu::xml::pipeline::EventFilter
{

public: // actually package-private
  XIncludeFilter$Scrubber(::gnu::xml::pipeline::XIncludeFilter *, ::gnu::xml::pipeline::EventFilter *);
public:
  virtual void setDocumentLocator(::org::xml::sax::Locator *);
  virtual void startDocument();
  virtual void endDocument();
private:
  void reject(::java::lang::String *);
public:
  virtual void startDTD(::java::lang::String *, ::java::lang::String *, ::java::lang::String *);
  virtual void endDTD();
  virtual void skippedEntity(::java::lang::String *);
public: // actually package-private
  ::gnu::xml::pipeline::XIncludeFilter * __attribute__((aligned(__alignof__( ::gnu::xml::pipeline::EventFilter)))) this$0;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_xml_pipeline_XIncludeFilter$Scrubber__
