
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_CORBA_Poa_gnuPOA$RefTemplate__
#define __gnu_CORBA_Poa_gnuPOA$RefTemplate__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace CORBA
    {
      namespace Poa
      {
          class gnuPOA;
          class gnuPOA$RefTemplate;
      }
    }
  }
  namespace org
  {
    namespace omg
    {
      namespace CORBA
      {
          class Object;
      }
    }
  }
}

class gnu::CORBA::Poa::gnuPOA$RefTemplate : public ::java::lang::Object
{

public: // actually package-private
  gnuPOA$RefTemplate(::gnu::CORBA::Poa::gnuPOA *);
public:
  virtual JArray< ::java::lang::String * > * adapter_name();
  virtual ::java::lang::String * orb_id();
  virtual ::java::lang::String * server_id();
  virtual ::org::omg::CORBA::Object * make_object(::java::lang::String *, JArray< jbyte > *);
  virtual JArray< ::java::lang::String * > * _truncatable_ids();
private:
  static const jlong serialVersionUID = 1LL;
public: // actually package-private
  JArray< ::java::lang::String * > * __attribute__((aligned(__alignof__( ::java::lang::Object)))) m_adapter_name;
  ::gnu::CORBA::Poa::gnuPOA * this$0;
public:
  static ::java::lang::Class class$;
};

#endif // __gnu_CORBA_Poa_gnuPOA$RefTemplate__
